// src/index.ts
import { WriteStream, createWriteStream } from "fs";

// src/E/Level.ts
var Level = /* @__PURE__ */ ((Level2) => {
  Level2["Debug"] = "Debug";
  Level2["Info"] = "Info";
  Level2["Warn"] = "Warn";
  Level2["Error"] = "Error";
  return Level2;
})(Level || {});
var Level_default = Level;

// src/index.ts
var INTERVAL = 1e3 * 60;
var LEVELS = ["Debug", "Info", "Warn", "Error"];
var DEFAULT_LEVEL = Level_default.Debug;
var DEFAULT_PATH = "./log";
function src_default(option) {
  let { path, level, onConsole } = option;
  path = path || DEFAULT_PATH;
  level = level || DEFAULT_LEVEL;
  if (!LEVELS.includes(level)) {
    level = DEFAULT_LEVEL;
  }
  onConsole = onConsole === true ? true : false;
  const logger = new Logger(option);
  console.log(`\x1B[32mdwLogger-\u8F38\u51FA\u7D1A\u5225:${level}\x1B[39m`);
  console.log(`\x1B[32mdwLogger-\u8DEF\u5F91:${path}\x1B[39m`);
  console.log(`\x1B[32mdwLogger-\u8F38\u51FA\u81F3console:${onConsole}\x1B[39m`);
  return logger;
}
var Logger = class {
  constructor(option) {
    const { path, level, onConsole } = option;
    this.path = path;
    this.level = level;
    this.onConsole = onConsole;
    this.createNewFile();
    setInterval(() => {
      if (getYMD() !== this.getDate()) {
        this.createNewFile();
      }
    }, INTERVAL);
  }
  getDate() {
    return this.date;
  }
  createNewFile() {
    const path = this.path;
    const ws = this.writeStream;
    this.date = getYMD();
    if (ws instanceof WriteStream && ws.writable) {
      ws.end();
    }
    this.writeStream = createWriteStream(`${path}/${getYMD("-")}.log`, { encoding: "utf8", flags: "a" });
  }
  append(log) {
    this.writeStream.write(`${this.getTimestamp()} - ${log}
`);
  }
  getTimestamp() {
    const now = /* @__PURE__ */ new Date();
    const hour = now.getHours().toString();
    const min = now.getMinutes().toString();
    const sec = now.getSeconds().toString();
    const micro = now.getMilliseconds().toString();
    return `${this.date} ${hour.padStart(2, "0")}:${min.padStart(2, "0")}:${sec.padStart(2, "0")}.${micro.padStart(3, "0")}`;
  }
  debug(log) {
    if (getPriority(this.level) > getPriority(Level_default.Debug))
      return;
    log = `\x1B[36mDebug\x1B[39m : \x1B[36m${log}\x1B[39m`;
    this.exe(log);
  }
  info(log) {
    if (getPriority(this.level) > getPriority(Level_default.Info))
      return;
    log = `\x1B[32mInfo\x1B[39m : \x1B[32m${log}\x1B[39m`;
    this.exe(log);
  }
  warn(log) {
    if (getPriority(this.level) > getPriority(Level_default.Warn))
      return;
    log = `\x1B[33mWarn\x1B[39m : \x1B[33m${log}\x1B[39m`;
    this.exe(log);
  }
  error(log) {
    if (getPriority(this.level) > getPriority(Level_default.Error))
      return;
    log = `\x1B[31mError\x1B[39m : \x1B[31m${log}\x1B[39m`;
    this.exe(log);
  }
  exe(line) {
    this.append(line);
    this.onConsole && this.print(line);
  }
  print(line) {
    console.log(`${line}`);
  }
};
function getYMD(split = "/") {
  const now = /* @__PURE__ */ new Date();
  const year = now.getFullYear();
  const month = (now.getMonth() + 1).toString();
  const date = now.getDate().toString();
  return `${year}${split}${month.padStart(2, "0")}${split}${date.padStart(2, "0")}`;
}
function getPriority(level) {
  if (level === Level_default.Debug)
    return 10;
  else if (level === Level_default.Info)
    return 20;
  else if (level === Level_default.Warn)
    return 30;
  else if (level === Level_default.Error)
    return 40;
  else
    return 0;
}
export {
  Level_default as Level,
  Logger,
  src_default as default
};
//# sourceMappingURL=index.js.map